@@ -524,4 +524,5 @@ def insert_to_table_from_dataframe(
     """
     client = connect(service_account_file=service_account_file)
     table_ref = get_table_ref(client, dataset_id, table_name)
-    return client.insert_rows_from_dataframe(table_ref, data)
+    table = client.get_table(table_ref)
+    return client.insert_rows_from_dataframe(table, data)
